@@ -232,6 +232,7 @@ class Representation:
         :param bar: Progress bar to update upon completion
         """
         cmd = [
+            "gm",
             "convert",
             "-size",
             f"{self.dim.width}x{self.dim.height}",
@@ -281,7 +282,8 @@ class Representation:
         )
 
 
-    async def _dim(self, proc):
+    @staticmethod
+    async def _dim(proc):
         """Receive and compute image dimensions for initial representation
 
         :param proc: qrexec-client-vm process
